@@ -17,6 +17,7 @@ from .objects.cpu import Cpu
 from .objects.display import DisplayBase
 from .objects.events import Event, EventBase
 from .objects.filesystem import Filesystem
+from .objects.filesystem.file import FilesystemFile
 from .objects.graphics import Graphics
 from .objects.information import Information
 from .objects.keyboard.payload import KeyboardPayload
@@ -203,6 +204,31 @@ class Bridge(BridgeBase):
         self._filesystem = Filesystem(await self.async_get("/filesystem"))
         return self._filesystem
 
+    async def async_get_filesystem_files(self, path: str) -> List[FilesystemFile]:
+        """Get filesystem files information"""
+        files = await self.async_get(f"/filesystem/files?path={path}")
+        return [FilesystemFile(file) for file in files]
+
+    async def async_get_filesystem_file(self, path: str) -> FilesystemFile:
+        """Get filesystem files information"""
+        return FilesystemFile(
+            await self.async_get(f"/filesystem/files/file?path={path}")
+        )
+
+    async def async_get_filesystem_file_data(self, path: str) -> any:
+        """Get filesystem file data"""
+        return await self.async_get(f"/filesystem/files/file/data?path={path}")
+
+    def get_filesystem_file_data_url(self, path: str) -> str:
+        """Get filesystem file data url"""
+        return f"{self._base_url}/filesystem/files/file/data?apiKey={self._api_key}&path={path}"
+
+    async def async_upload_filesystem_file(self, path: str) -> any:
+        """Upload file to filesystem"""
+        return FilesystemFile(
+            await self.async_post(f"/filesystem/files/file/data?path={path}")
+        )
+
     async def async_get_graphics(self) -> Graphics:
         """Get graphics information"""
         self._graphics = Graphics(await self.async_get("/graphics"))
